import sentry_sdk
from sentry_sdk.integrations.threading import ThreadingIntegration

def construct_dsn(config):
    return f"{config['protocol']}://{config['public_key']}@{config['host']}:{config['port']}/{config['project_id']}"

def init_drcode(config):
    dsn = construct_dsn(config)
    
    sentry_sdk.init(
        dsn=dsn,
        integrations=[
            ThreadingIntegration(propagate_hub=True),
        ],
        traces_sample_rate=config.get('traces_sample_rate', 1.0),
        profiles_sample_rate=config.get('profiles_sample_rate', 1.0),
    )



from setuptools import setup, find_packages

setup(
    name='drcodecover',
   version='0.1.4',
    packages=find_packages(),
    install_requires=[
        'sentry-sdk',
    ],
    author='Mohd Nadeem',
    author_email='codewithnadeem@gmail.com',
    description='A special package for drcode',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/codewithnadeem14502/drcode-wrapper-python',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)


import unittest
from drcodecover.drcodecover import construct_dsn, init_drcode
import sentry_sdk

class TestDrcodecover(unittest.TestCase):

    def test_construct_dsn(self):
        config = {
            'protocol': 'https',
            'public_key': 'abc123',
            'host': 'sentry.io',
            'port': '443',
            'project_id': '12345'
        }
        dsn = construct_dsn(config)
        expected_dsn = 'https://abc123@sentry.io:443/12345'
        self.assertEqual(dsn, expected_dsn)

    def test_init_drcode(self):
        config = {
            'protocol': 'https',
            'public_key': 'abc123',
            'host': 'sentry.io',
            'port': '443',
            'project_id': '12345'
        }
        try:
            init_drcode(config)
            # Check if Sentry has been initialized correctly
            self.assertIsNotNone(sentry_sdk.Hub.current.client, "Sentry SDK should be initialized")
        except Exception as e:
            self.fail(f'init_drcode raised an exception: {e}')

if __name__ == '__main__':
    unittest.main()
